import Image from 'next/image';
import { ChangeEvent, useState } from 'react';
import lensIcon from '@/assets/vectors/icons/lens.svg';

export const SearchBar = (): JSX.Element => {
  const [searchValue, setSearchValue] = useState<string>('');

  const onSearchChange = (event: ChangeEvent<HTMLInputElement>): void => {
    setSearchValue(event.target.value);
  };

  return (
    <div className="relative" data-testid="search-bar">
      <input
        value={searchValue}
        name="search-input"
        aria-label="search-input"
        data-testid="search-input"
        onChange={onSearchChange}
        className="h-9 w-72 rounded-[64px] border border-transparent bg-cultured px-4 py-2.5 text-xs font-medium text-font-400 outline-none  hover:border-greyscale-600 focus:border-greyscale-600"
      />
      <Image
        src={lensIcon}
        alt="lens icon"
        height={16}
        width={16}
        className="absolute right-4 top-2.5"
      />
    </div>
  );
};
