import Map from 'ol/Map';
import { MutableRefObject, useEffect, useRef, useState } from 'react';
import { MapInstance } from '../MapViewer.types';
import { useOlMapConfig } from './useOlMapConfig';
import { useOlMapInit } from './useOlMapInit';

interface UseOlMapOutput {
  mapRef: MutableRefObject<null | HTMLDivElement>;
  mapInstance: MapInstance;
}

type UseOlMap = () => UseOlMapOutput;

export const useOlMap: UseOlMap = () => {
  const mapRef = useRef<null | HTMLDivElement>(null);
  const [mapInstance, setMapInstance] = useState<MapInstance>(undefined);
  const mapConfig = useOlMapConfig();
  useOlMapInit();

  useEffect(() => {
    // checking if innerHTML is empty due to possibility of target element cloning by openlayers map instance
    if (!mapRef.current || mapRef.current.innerHTML !== '') {
      return;
    }

    const map = new Map({
      target: mapRef.current,
    });

    setMapInstance(map);
  }, []);

  useEffect(() => {
    if (!mapInstance) {
      return;
    }

    mapInstance.setView(mapConfig.view);
    mapInstance.setLayers(mapConfig.layers);
  }, [mapConfig, mapInstance]);

  return {
    mapRef,
    mapInstance,
  };
};
